..
    Developer note: the files in the generated folder are generated by the file
    `sphinx_dd_extension/autodoc.py`.

.. _`reference`:
.. _`ids reference`:

IDS reference
=============

.. toctree::
    :name: dd-reference-toc
    :glob:
    :maxdepth: 1

    generated/ids/*
